@@ -161,6 +161,20 @@ pseudo_init_client(void) {
 		pseudo_set_value("PSEUDO_DISABLED", "0");
 	}
 
+	/* in child processes, PSEUDO_UNLOAD may become set to
+	 * some truthy value, in which case we're being asked to
+	 * remove pseudo from the LD_PRELOAD. We need to make sure
+	 * this value gets loaded into the internal variables.
+	 *
+	 * If we've been told to unload, but are still available
+	 * we need to act as if unconditionally disabled.
+	 */
+	env = getenv("PSEUDO_UNLOAD");
+	if (env) {
+		pseudo_set_value("PSEUDO_UNLOAD", env);
+		pseudo_disabled=1;
+	}
+
 	/* Setup global items needed for pseudo to function... */
 	if (!pseudo_inited) {
 		/* Ensure that all of the values are reset */
@@ -641,7 +655,7 @@ client_spawn_server(void) {
 		}
 		/* and now, execute the server */
 
-		pseudo_set_value("PSEUDO_RELOADED", "YES");
+		pseudo_set_value("PSEUDO_UNLOAD", "YES");
 		pseudo_setupenv();
 		pseudo_dropenv(); /* drop PRELINK_LIBRARIES */
 
@@ -660,6 +674,8 @@ client_ping(void) {
 	char tagbuf[pseudo_path_max()];
 	char *tag = pseudo_get_value("PSEUDO_TAG");
 
+	memset(&ping, 0, sizeof(ping));
+
 	ping.type = PSEUDO_MSG_PING;
 	ping.op = OP_NONE;
 
@@ -972,6 +988,8 @@ base_path(int dirfd, const char *path, int leave_last) {
 		if (dirfd != -1 && dirfd != AT_FDCWD) {
 			if (dirfd >= 0) {
 				basepath = fd_path(dirfd);
+			}
+			if (basepath) {
 				baselen = strlen(basepath);
 			} else {
 				pseudo_diag("got *at() syscall for unknown directory, fd %d\n", dirfd);
@@ -1112,7 +1130,10 @@ pseudo_client_op(pseudo_op_t op, int access, int fd, int dirfd, const char *path
 	if (path) {
 		pseudo_debug(2, " %s", path);
 	}
-	if (fd != -1) {
+	/* for OP_RENAME in renameat, "fd" is also used for the
+	 * second dirfd.
+	 */
+	if (fd != -1 && op != OP_RENAME) {
 		pseudo_debug(2, " [fd %d]", fd);
 	}
 	if (buf) {
